.. _indent_example-name:

!!!!!!!!!!!!!!
indent_example
!!!!!!!!!!!!!!

.. meta::
   :keywords: indent_example,indent,example,discussion,python,docstring,this,file

.. index:: indent_example, indent

.. _indent_example-title:

Indent Example
##############

.. contents::
   :local:

.. index:: discussion

.. _indent_example@Discussion:

Discussion
**********
The file below demonstrates a single indentation for an entire xrst page.
(See :ref:`example_ad_double@xrst_indent` for an example
that has different indentation for different parts of a page.)
Note that underling headings works even though it is indented.

.. index:: python, docstring

.. _indent_example@Python Docstring:

Python Docstring
****************
This example input is a python docstring for the factorial function
defined in this file, but it is documenting indentation instead
of the function. See :ref:`docstring_example-name` for an alternative
way to construct a docstring.

.. _indent_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/indent.py
   :language: py
